@@ -1,33 +1,35 @@
 #!/usr/bin/perl -w
 
 # speed.pl: compare different versions of Text-CSV* modules
-#	   (m)'08 [07 Apr 2008] Copyright H.M.Brand 2007-2014
+#	   (m)'08 [07 Apr 2008] Copyright H.M.Brand 2007-2016
 
 require 5.006001;
 use strict;
 
 use IO::Handle;
 use Text::CSV_XS;
-use Benchmark qw(:all :hireswallclock);
+use Benchmark "timethese";
+eval { Benchmark->import (":hireswallclock"); };
 
 our $csv = Text::CSV_XS->new ({ eol => "\n" });
 
 my $duration = int (shift || 2);
-our @fields1 = (
-    "Wiedmann", "Jochen",
-    "Am Eisteich 9",
-    "72555 Metzingen",
-    "Germany",
-    "+49 7123 14881",
-    "joe\@ispsoft,de");
-our @fields10  = (@fields1) x 10;
-our @fields100 = (@fields1) x 100;
+my  @fields = (
+    "Holmes", "Sherlock",
+    "Baker street", 221, "B",
+    72555, "London", "NW1 6XE",
+    "United Kingdom",
+    "+44 7123 84567",
+    "sherlock\@holmes,co.uk");
+our @fields1   = (@fields) x 1;
+our @fields10  = (@fields) x 10;
+our @fields100 = (@fields) x 100;
 
 $csv->combine (@fields1  ); our $str1   = $csv->string;
 $csv->combine (@fields10 ); our $str10  = $csv->string;
 $csv->combine (@fields100); our $str100 = $csv->string;
 
-timethese (-1.2,{
+timethese (-1.5,{
 
     "combine   1"	=> q{ $csv->combine (@fields1  ) },
     "combine  10"	=> q{ $csv->combine (@fields10 ) },
